| Title: | A Meta-Package for Relational Event History Analysis |
|---|---|
| Description: | A unified workflow for relational event modeling by re-exporting core functions from 'remify', 'remstats', and 'remstimate'. Supports tie-oriented and actor-oriented modeling with frequentist and Bayesian estimation. Methods are described in Butts (2008) <doi:10.1111/j.1467-9531.2008.00203.x> and Stadtfeld and Block (2017) <doi:10.1177/0081175017709295>. |
| Authors: | Joris Mulder [aut, cre], Giuseppe Arena [aut], Roger Leenders [aut], Marlyne Meijerink-Bosman [aut], Rumana Lakdawala [aut], Fabio Generoso Vieira [aut], Mahdi Shafiee Kamalabad [ctb], Diana Karimova [ctb] |
| Maintainer: | Joris Mulder <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-28 18:14:30 UTC |
| Source: | https://github.com/cran/remverse |
The remverse package loads an ensemble of R packages for working with Relational Event Histories (REH): preprocessing event sequences (remify), computing network statistics (remstats), and estimating relational event models (remstimate).
Maintainer: Joris Mulder [email protected]
Authors:
Giuseppe Arena [email protected]
Roger Leenders [email protected]
Marlyne Meijerink-Bosman [email protected]
Rumana Lakdawala [email protected]
Fabio Generoso Vieira [email protected]
Other contributors:
Mahdi Shafiee Kamalabad [email protected] [contributor]
Diana Karimova [email protected] [contributor]
library(remverse) # Load example data data("edgelist0") data("edgelist0_actors") # Preprocess data reh <- remify(edgelist = edgelist0, model = "tie", directed = TRUE, event_type = "setting", extend_riskset_by_type = TRUE) # Compute statistics stats <- remstats(reh, tie_effects = ~ inertia(scaling="std", consider_type = "ignore") + reciprocity(scaling="std", consider_type = "separate") + same("job", attr_actors = edgelist0_actors), start = 10) # Fit model fit <- remstimate(reh, stats) summary(fit) # Check diagnostics diag_fit <- diagnostics(fit, reh, stats) print(diag_fit) plot(fit, reh, diag_fit)library(remverse) # Load example data data("edgelist0") data("edgelist0_actors") # Preprocess data reh <- remify(edgelist = edgelist0, model = "tie", directed = TRUE, event_type = "setting", extend_riskset_by_type = TRUE) # Compute statistics stats <- remstats(reh, tie_effects = ~ inertia(scaling="std", consider_type = "ignore") + reciprocity(scaling="std", consider_type = "separate") + same("job", attr_actors = edgelist0_actors), start = 10) # Fit model fit <- remstimate(reh, stats) summary(fit) # Check diagnostics diag_fit <- diagnostics(fit, reh, stats) print(diag_fit) plot(fit, reh, diag_fit)
A simulated event sequence among 5 actors using the endogenous effects: inertia, reciprocity, and itp.
data(edgelist0)data(edgelist0)
A dataframe with 1000 rows and 3 variables:
time of the event
the first actor involved in the event
the second actor involved in the event
the setting of an event: X or Y
Simulated relational event sequence among 5 actors in a social network.
data(edgelist0)data(edgelist0)
Actor attributes of actors in event sequence edgelist0
data(edgelist0_actors)data(edgelist0_actors)
A dataframe with 1000 rows and 3 variables:
label of the actor
the time of measurement of the attribute
the job of the actor
Simulated attributes of 5 actors in a social network.
data(edgelist0_actors)data(edgelist0_actors)