| Title: | A Meta-Package for Relational Event History Analysis |
| Version: | 0.1.0 |
| Maintainer: | Joris Mulder <j.mulder3@tilburguniversity.edu> |
| Description: | A unified workflow for relational event modeling by re-exporting core functions from 'remify', 'remstats', and 'remstimate'. Supports tie-oriented and actor-oriented modeling with frequentist and Bayesian estimation. Methods are described in Butts (2008) <doi:10.1111/j.1467-9531.2008.00203.x> and Stadtfeld and Block (2017) <doi:10.1177/0081175017709295>. |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Depends: | R (≥ 4.0), remify (≥ 4.0.0), remstats (≥ 4.0.0), remstimate (≥ 3.0.0) |
| Suggests: | knitr, rmarkdown |
| LazyData: | true |
| VignetteBuilder: | knitr |
| NeedsCompilation: | no |
| Packaged: | 2026-05-22 09:21:07 UTC; jorismulder |
| Author: | Joris Mulder [aut, cre], Giuseppe Arena [aut], Roger Leenders [aut], Marlyne Meijerink-Bosman [aut], Rumana Lakdawala [aut], Fabio Generoso Vieira [aut], Mahdi Shafiee Kamalabad [ctb], Diana Karimova [ctb] |
| Repository: | CRAN |
| Date/Publication: | 2026-05-28 13:30:08 UTC |
remverse: A Collection of R Packages for Relational Event Modeling
Description
The remverse package loads an ensemble of R packages for working with Relational Event Histories (REH): preprocessing event sequences (remify), computing network statistics (remstats), and estimating relational event models (remstimate).
Author(s)
Maintainer: Joris Mulder j.mulder3@tilburguniversity.edu
Authors:
Giuseppe Arena g.arena@tilburguniversity.edu
Roger Leenders r.t.a.j.leenders@tilburguniversity.edu
Marlyne Meijerink-Bosman m.l.meijerink@tilburguniversity.edu
Rumana Lakdawala r.j.lakdawala@tilburguniversity.edu
Fabio Generoso Vieira f.v.generosovieira@tilburguniversity.edu
Other contributors:
Mahdi Shafiee Kamalabad m.shafiee@tilburguniversity.edu [contributor]
Diana Karimova d.karimova@tilburguniversity.edu [contributor]
Examples
library(remverse)
# Load example data
data("edgelist0")
data("edgelist0_actors")
# Preprocess data
reh <- remify(edgelist = edgelist0,
model = "tie",
directed = TRUE,
event_type = "setting",
extend_riskset_by_type = TRUE)
# Compute statistics
stats <- remstats(reh,
tie_effects = ~ inertia(scaling="std", consider_type = "ignore") +
reciprocity(scaling="std", consider_type = "separate") +
same("job", attr_actors = edgelist0_actors),
start = 10)
# Fit model
fit <- remstimate(reh, stats)
summary(fit)
# Check diagnostics
diag_fit <- diagnostics(fit, reh, stats)
print(diag_fit)
plot(fit, reh, diag_fit)
Simulated relational event history
Description
A simulated event sequence among 5 actors using the endogenous effects: inertia, reciprocity, and itp.
Usage
data(edgelist0)
Format
A dataframe with 1000 rows and 3 variables:
- time
time of the event
- actor1
the first actor involved in the event
- actor2
the second actor involved in the event
- setting
the setting of an event:
XorY
Simulated relational event sequence among 5 actors in a social network.
Examples
data(edgelist0)
Simulated relational event history
Description
Actor attributes of actors in event sequence edgelist0
Usage
data(edgelist0_actors)
Format
A dataframe with 1000 rows and 3 variables:
- name
label of the actor
- time
the time of measurement of the attribute
- job
the job of the actor
Simulated attributes of 5 actors in a social network.
Examples
data(edgelist0_actors)